@@ -16,10 +16,25 @@ class NestedResolvers(BaseModel):
     def has(self, edge: str) -> bool:
         return edge in self.d
 
-    def add(self, edge: str, resolver: "Resolver") -> None:
+    def add(
+        self,
+        edge: str,
+        resolver: "Resolver",
+        ignore_if_subset: bool = False,
+        make_first: bool = False,
+    ) -> None:
         if not self.has(edge):
             self.d[edge] = []
-        self.d[edge].append(resolver)
+        if ignore_if_subset:
+            for r in list(self.get(edge)):
+                if resolver.is_subset(r):
+                    resolver = r
+                    self.get(edge).remove(resolver)
+                    break
+        if make_first:
+            self.d[edge].insert(0, resolver)
+        else:
+            self.d[edge].append(resolver)
 
     def has_subset(self, edge: str, resolver: "Resolver") -> bool:
         resolvers = self.get(edge)
@@ -74,10 +89,3 @@ class NestedResolvers(BaseModel):
         except (IndexError, ValueError) as e:
             print(f"{e=}, {field_name=}")
             return None
-
-    def upsert(self, edge: str, resolver: "Resolver") -> None:
-        """If a superset of this resolver exists, do nothing. Otherwise, add it."""
-        for r in self.get(edge):
-            if resolver.is_subset(r):
-                return None
-        self.add(edge=edge, resolver=resolver)
